<p align="center">
<a href="https://github.com/spapanik/dj_settings/actions/workflows/build.yml"><img alt="Build" src="https://github.com/spapanik/dj_settings/actions/workflows/build.yml/badge.svg"></a>
<a href="https://lgtm.com/projects/g/spapanik/dj_settings/alerts/"><img alt="Total alerts" src="https://img.shields.io/lgtm/alerts/g/spapanik/dj_settings.svg"/></a>
<a href="https://github.com/spapanik/dj_settings/blob/main/LICENSE.txt"><img alt="License" src="https://img.shields.io/github/license/spapanik/dj_settings"></a>
<a href="https://pypi.org/project/dj_settings"><img alt="PyPI" src="https://img.shields.io/pypi/v/dj_settings"></a>
<a href="https://pepy.tech/project/dj_settings"><img alt="Downloads" src="https://pepy.tech/badge/dj_settings"></a>
<a href="https://github.com/psf/black"><img alt="Code style" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>
